vitamin b: https://en.wikipedia.org/wiki/B_vitamins { "names": [ "vitamin b" ], "unites": [ ], "unites probable eventualities": [ ] } { "names": [ "vitamin b1", "thiamin" ], "unites": [] } { "names": [ "vitamin b2", "riboflavin" ], "unites": [] } { "names": [ "vitamin b3" ], "unites": [ "niacin", "nicotinamide", "nicotinamide riboside" ] } { "names": [ "vitamin b5", "Pantothenic acid" ], "unites": [] } { "names": [ "vitamin b6" ], "unites": [ "pyridoxine", "pyridoxal", "pyridoxamine" ] } { "names": [ "vitamin b7", "biotin", "vitamin h" ], "unites": [] } { "names": [ "vitamin b9", "folate", "folacin" ], "unites": [] } { "names": [ "vitamin b12", "cobalamin" ], "unites": [] }